@@ -247,7 +247,7 @@ def intintensity(data,alpha,alphaerr,qmin=-np.inf,qmax=np.inf,m=0):
     if alpha<1:
         raise ValueError('m+alpha should be larger than 1. alpha: %f m: %f (m+alpha): %f',(-alpha,m,m-alpha))
     alpha=alpha-m
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     q2=data1['q'].max()
     q1=data['q'].min()
     
@@ -263,23 +263,6 @@ def intintensity(data,alpha,alphaerr,qmin=-np.inf,qmax=np.inf,m=0):
     #print ret3, "+/-",dret3
     
     return ret1+ret2+ret3,np.sqrt(dret1**2+dret2**2+dret3**2)
-def trimq(data,qmin=-np.inf,qmax=np.inf):
-    """Trim the 1D scattering data to a given q-range
-    
-    Inputs:
-        data: scattering data
-        qmin: lowest q-value to include
-        qmax: highest q-value to include
-    
-    Output:
-        an 1D scattering data dictionary, with points whose q-values were not
-            smaller than qmin and not larger than qmax.
-    """
-    indices=(data['q']<=qmax) & (data['q']>=qmin)
-    data1={}
-    for k in data.keys():
-        data1[k]=data[k][indices]
-    return data1
 def subconstbg(data,bg,bgerror):
     """Subtract a constant background from the 1D dataset.
     
@@ -345,7 +328,7 @@ def shullroess(data,qmin=-np.inf,qmax=np.inf,gui=False):
     ax3=pylab.axes((leftborder,bottomborder,width,height))
     ax4=pylab.axes(((1-rightborder-width),bottomborder,width,height))
     
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
 
     if gui:
         axq1=pylab.axes((leftborder,bottomborder/7.0,1-rightborder-leftborder-0.1,bottomborder/7.0))
@@ -358,7 +341,7 @@ def shullroess(data,qmin=-np.inf,qmax=np.inf,gui=False):
         ax2.clear()
         ax3.clear()
         ax4.clear()
-        data1=trimq(data,qmin,qmax)
+        data1=utils.trimq(data,qmin,qmax)
         Iexp=np.array(data1['Intensity'])
         qexp=np.array(data1['q'])
         errexp=np.array(data1['Error'])
@@ -459,7 +442,7 @@ def guiniercrosssectionfit(data,qmin=-np.inf,qmax=np.inf,testimage=False,smearin
         the calculated error of Rg
         the calculated error of the prefactor
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=data1['q']**2;
     err1=np.absolute(data1['Error']/data1['Intensity']*data1['q'])
     y1=np.log(data1['Intensity'])*data1['q']
@@ -472,7 +455,7 @@ def guiniercrosssectionfit(data,qmin=-np.inf,qmax=np.inf,testimage=False,smearin
         pylab.plot(data1['q']**2,Rgcs*data1['q']**2+Gcs,'-',color='red');
         pylab.xlabel('$q^2$ (1/%c$^2$)' % 197)
         pylab.ylabel('$q\ln I$')
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Guinier radius: %f +/- %f\nFactor: %f +/- %f\nRg*q_max: %f\n%f<=q<=%f' %(np.sqrt(-Rgcs*2),1/np.sqrt(-Rgcs)*dRgcs,Gcs,dGcs,np.sqrt(-Rgcs*2)*data1['q'].max(),data1['q'].min(),data1['q'].max()),ha='right',va='top',transform=pylab.gca().transAxes)
@@ -493,7 +476,7 @@ def guinierthicknessfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         the calculated error of Rgt
         the calculated error of the prefactor
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=data1['q']**2;
     err1=np.absolute(data1['Error']/data1['Intensity']*data1['q']**2)
     y1=np.log(data1['Intensity'])*data1['q']**2
@@ -506,7 +489,7 @@ def guinierthicknessfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         pylab.plot(data1['q']**2,Rgt*data1['q']**2+Gt,'-',color='red');
         pylab.xlabel('$q^2$ (1/%c$^2$)' % 197)
         pylab.ylabel('$q^2\ln I$')
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Guinier radius: %f +/- %f\nFactor: %f +/- %f\nRg*q_max: %f\n%f<=q<=%f' %(np.sqrt(-Rgt),0.5/np.sqrt(-Rgt)*dRgt,Gt,dGt,np.sqrt(-Rgt)*data1['q'].max(),data1['q'].min(),data1['q'].max()),ha='right',va='top',transform=pylab.gca().transAxes)
@@ -527,7 +510,7 @@ def guinierfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         the calculated error of Rg
         the calculated error of the prefactor
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=data1['q']**2;
     err1=np.absolute(data1['Error']/data1['Intensity']);
     y1=np.log(data1['Intensity']);
@@ -540,7 +523,7 @@ def guinierfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         pylab.plot(data1['q']**2,Rg*data1['q']**2+G,'-',color='red');
         pylab.xlabel('$q^2$ (1/%c$^2$)' % 197)
         pylab.ylabel('ln I');
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Guinier radius: %f +/- %f\nFactor: %f +/- %f\nRg*q_max: %f\n%f<=q<=%f' %(np.sqrt(-Rg*3),1.5/np.sqrt(-Rg*3)*dRg,G,dG,np.sqrt(-Rg*3)*data1['q'].max(),data1['q'].min(),data1['q'].max()),ha='right',va='top',transform=pylab.gca().transAxes)
@@ -561,7 +544,7 @@ def porodfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         the calculated error of the constant background
         the calculated error of the Porod coefficient
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=data1['q']**4;
     err1=data1['Error']*x1;
     y1=data1['Intensity']*x1;
@@ -574,7 +557,7 @@ def porodfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         pylab.plot(data1['q']**4,a*data1['q']**4+b,'-',color='red');
         pylab.xlabel('$q^4$ (1/%c$^4$)' % 197)
         pylab.ylabel('I$q^4$');
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Constant background: %f +/- %f\nPorod coefficient: %f +/- %f\n%f<=q<=%f' %(a,b,aerr,berr,data1['q'].min(),data1['q'].max()),ha='right',va='top',transform=pylab.gca().transAxes)
@@ -595,7 +578,7 @@ def powerfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         the calculated error of the exponent
         the calculated error of the prefactor
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=np.log(data1['q']);
     err1=np.absolute(data1['Error']/data1['Intensity']);
     y1=np.log(data1['Intensity']);
@@ -612,7 +595,7 @@ def powerfit(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         pylab.loglog(data1['q'],np.exp(b)*pow(data1['q'],a),'-',color='red');
         pylab.xlabel('$q$ (1/%c)' % 197)
         pylab.ylabel('I');
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Exponent: %f +/- %f\nCoefficient: %f +/- %f\n%f<=q<=%f' %(xp,dxp,coeff,dcoeff,data1['q'].min(),data1['q'].max()),ha='right',va='top',transform=pylab.gca().transAxes)
@@ -637,7 +620,7 @@ def powerfitwithlinearbackground(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         the calculated error of the constant background
         the calculated error of the first order part of the background
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=data1['q'];
     err1=data1['Error'];
     y1=data1['Intensity'];
@@ -657,7 +640,7 @@ def powerfitwithlinearbackground(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         pylab.loglog(data1['q'],res[0][1]*pow(data1['q'],res[0][0])+res[0][2]+data1['q']*res[0][3],'-',color='red');
         pylab.xlabel('$q$ (1/%c)' % 197)
         pylab.ylabel('I');
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Exponent: %f +/- %f\nCoefficient: %f +/- %f\nConstant background: %f +/- %f\nLinear term: %f +/- %f\n%f<=q<=%f' %(res[0][0],np.sqrt(res[1][0][0]),\
@@ -683,10 +666,11 @@ def powerfitwithbackground(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         the calculated error of the prefactor
         the calculated error of the constant background
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     x1=data1['q'];
     err1=data1['Error'];
     y1=data1['Intensity'];
+    costfunc=lambda p,x,y,err:(y-x**p[0]*p[1]-p[2])/err
     def costfunc(p,x,y,err):
         res= (y-x**p[0]*p[1]-p[2])/err
         return res
@@ -702,7 +686,7 @@ def powerfitwithbackground(data,qmin=-np.inf,qmax=np.inf,testimage=False):
         pylab.loglog(data1['q'],res[0][1]*pow(data1['q'],res[0][0])+res[0][2],'-',color='red');
         pylab.xlabel('$q$ (1/%c)' % 197)
         pylab.ylabel('I');
-        a=pylab.axis()
+        #a=pylab.axis()
         pylab.text(fitting_testimage_horizpos,\
                    fitting_testimage_vertpos,
                    'Exponent: %f +/- %f\nCoefficient: %f +/- %f\nConstant background: %f +/- %f\n%f<=q<=%f' %(res[0][0],np.sqrt(res[1][0][0]),\
@@ -734,7 +718,7 @@ def unifiedfit(data,B,G,Rg,P,qmin=-np.inf,qmax=np.inf,maxiter=1000):
         the error of the Guinier prefactor
         the error of the radius of gyration
     """
-    data=trimq(data,qmin,qmax)
+    data=utils.trimq(data,qmin,qmax)
     def fitfun(data,x,y,err):
         G=data[0]
         B=data[1]
@@ -762,7 +746,7 @@ def fitspheredistribution(data,distfun,R,params,qmin=-np.inf,qmax=np.inf,testima
         paramsfitted: list of the fitted parameters plus a scaling factor
             added as the last.
     """
-    data1=trimq(data,qmin,qmax)
+    data1=utils.trimq(data,qmin,qmax)
     q=data1['q']
     Int=data1['Intensity']
     Err=data1['Error']
